@@ -1,14 +1,9 @@
-# -*- coding: utf-8 -*-
-
 """Definition of the ACTED Project content type
 """
 
 
 from zope.interface import implements, directlyProvides
 
-from Products.Archetypes.public import * 
-from Products.ATExtensions.ateapi import *
-
 from Products.Archetypes import atapi
 from Products.ATContentTypes.content import base
 from Products.ATContentTypes.content import schemata
@@ -27,7 +22,6 @@ from acted.projects.config import ACTED_SECTORS
 from acted.projects.config import ACTED_DONORS
 from acted.projects.config import ACTED_YEARS
 
-import re
 
 
 ACTEDProjectSchema = schemata.ATContentTypeSchema.copy() + atapi.Schema((
@@ -91,11 +85,10 @@ ACTEDProjectSchema = schemata.ATContentTypeSchema.copy() + atapi.Schema((
         format='select',
         size=25
       ),
-#      accessor='getProjectDonor',
       vocabulary=ACTED_DONORS,
       enforceVocabulary=True,
       required=False,
-      searchable=False
+      searchable=True
     ),
 
 
@@ -124,37 +117,16 @@ ACTEDProjectSchema = schemata.ATContentTypeSchema.copy() + atapi.Schema((
       searchable=False
     ),
 
-    atapi.StringField(
-      name='projectBudget',
-      widget=atapi.StringWidget(
-          label=_(u'Budget'),
-          maxlength=20,
-          size=20
-      ),
-      required=False,
-      searchable=False
-    ),
-
-
     atapi.ReferenceField(
         name='projectReferences',
         widget=ReferenceBrowserWidget(
             label=_(u'Reference Files'),
-            restrict_browsing_to_startup_directory=False,
-            #base_query={'path': '/intranet/project-database/'},
-            show_indexes=True,
-            allow_browse=False,
-            #startup_directory='/intranet/project-database/',
-            #show_results_without_query=False,
-            available_indexes={'Title':'Title', 'SearchableText': 'Text in Document'},
-            default_search_index='Title'
       ),
       required=False,
       searchable=False,
       multiValued=True,
       allow_sorting=True,
       relationship='WorksWith',
-
       allowed_types=('Document','File','Image','Folder')
     )
 
@@ -182,25 +154,5 @@ class ACTEDProject(base.ATCTContent):
     
     # -*- Your ATSchema to Python Property Bridges Here ... -*-
 
-    # this added on 13 Nov to fix adding new projects problem when
-    # a project has one donor with a unicode name and one without
-    # also changed was the coding delaration at line 1
-
-    def setProjectDonor(self,value):
-        retArr = []
-        for donor in value:
-            retArr.append(donor)
-        self.getField('projectDonor').set(self, retArr)
-
-
-"""
-    def getProjectDonor(self):
-        theDonors = self.getField('projectDonor').get(self)
-        retval = ''
-        for theDonor in theDonors:
-            theDonor = re.sub('^-* ', '', theDonor)
-            retval = retval + theDonor + ', '
-        return retval[:-4]
-"""
 
 atapi.registerType(ACTEDProject, PROJECTNAME)
